@@ -1,8 +1,8 @@
-/* $Id: error.c,v 1.10 2006/03/10 21:43:08 jonz Exp $ */
+/* $Id: error.c,v 1.12 2006/05/14 15:53:51 jonz Exp $ */
 
 /*
  DSPAM
- COPYRIGHT (C) 2002-2006 DEEP LOGIC INC.
+ COPYRIGHT (C) 2002-2006 JONATHAN A. ZDZIARSKI
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
@@ -36,6 +36,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <stdarg.h>
+#include <errno.h>
 #ifdef HAVE_UNISTD_H
 #   include <unistd.h>
 #endif
@@ -92,8 +93,13 @@ LOG(int priority, const char *err, ... )
 
 #ifdef LOGFILE
   file = fopen(LOGFILE, "a");
-  fprintf(file, "%ld: [%s] %s\n", (long) getpid(), format_date_r(date), buf); 
-  fclose(file);
+  if (file) {
+    fprintf(file, "%ld: [%s] %s\n", (long) getpid(), format_date_r(date), buf); 
+    fclose(file);
+  } else {
+    fprintf(stderr, "%s: %s", LOGFILE, strerror(errno));
+    fprintf(stderr, "%ld: [%s] %s\n", (long)getpid(), format_date_r(date), buf);
+  }
 #endif
 
 #ifdef DAEMON
