@@ -1,8 +1,8 @@
-/* $Id: mysql_drv.c,v 1.67 2006/04/12 13:49:01 jonz Exp $ */
+/* $Id: mysql_drv.c,v 1.70 2006/05/13 01:12:59 jonz Exp $ */
 
 /*
  DSPAM
- COPYRIGHT (C) 2002-2006 DEEP LOGIC INC.
+ COPYRIGHT (C) 2002-2006 JONATHAN A. ZDZIARSKI
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
@@ -1062,11 +1062,7 @@ _ds_get_signature (DSPAM_CTX * CTX, struct _ds_spam_signature *SIG,
     return EINVAL;
   }
 
-  if (_ds_match_attribute(CTX->config->attributes, "MySQLReadSignaturesFromWriteDb", "on"))
-    dbh = s->dbt->dbh_write;
-  else
-    dbh = s->dbt->dbh_read;
-
+  dbh = _mysql_drv_sig_write_handle(CTX, s);
 
   if (!CTX->group || CTX->flags & DSF_MERGED)
     p = _mysql_drv_getpwnam (CTX, CTX->username);
@@ -1110,6 +1106,8 @@ _ds_get_signature (DSPAM_CTX * CTX, struct _ds_spam_signature *SIG,
     CTX->username = username;
     _ds_init_storage(CTX, (dbh_attached) ? dbt : NULL);
     s = (struct _mysql_drv_storage *) CTX->storage;
+
+    dbh = _mysql_drv_sig_write_handle(CTX, s);
   } else {
     uid = p->pw_uid;
   }
@@ -2508,3 +2506,14 @@ FAILURE:
   LOGDEBUG("_ds_init_storage() failed");
   return NULL;
 }
+
+MYSQL * _mysql_drv_sig_write_handle(
+    DSPAM_CTX *CTX,
+    struct _mysql_drv_storage *s)
+{
+  if (_ds_match_attribute(CTX->config->attributes, "MySQLReadSignaturesFromWriteDb", "on"))
+    return s->dbt->dbh_write;
+  else
+    return s->dbt->dbh_read;
+}
+
